(harmonic_based_morphometrics)=

# Harmonic-based morphometrics

## Elliptic Fourier analysis (EFA)

Elliptic Fourier analysis (EFA) is a method for extracting two-dimensional (2D) outline shapes of target objects .
